# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import szengine_pb2 as szengine__pb2

GRPC_GENERATED_VERSION = '1.72.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in szengine_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class SzEngineStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AddRecord = channel.unary_unary(
                '/szengine.SzEngine/AddRecord',
                request_serializer=szengine__pb2.AddRecordRequest.SerializeToString,
                response_deserializer=szengine__pb2.AddRecordResponse.FromString,
                _registered_method=True)
        self.CloseExport = channel.unary_unary(
                '/szengine.SzEngine/CloseExport',
                request_serializer=szengine__pb2.CloseExportRequest.SerializeToString,
                response_deserializer=szengine__pb2.CloseExportResponse.FromString,
                _registered_method=True)
        self.CountRedoRecords = channel.unary_unary(
                '/szengine.SzEngine/CountRedoRecords',
                request_serializer=szengine__pb2.CountRedoRecordsRequest.SerializeToString,
                response_deserializer=szengine__pb2.CountRedoRecordsResponse.FromString,
                _registered_method=True)
        self.DeleteRecord = channel.unary_unary(
                '/szengine.SzEngine/DeleteRecord',
                request_serializer=szengine__pb2.DeleteRecordRequest.SerializeToString,
                response_deserializer=szengine__pb2.DeleteRecordResponse.FromString,
                _registered_method=True)
        self.ExportCsvEntityReport = channel.unary_unary(
                '/szengine.SzEngine/ExportCsvEntityReport',
                request_serializer=szengine__pb2.ExportCsvEntityReportRequest.SerializeToString,
                response_deserializer=szengine__pb2.ExportCsvEntityReportResponse.FromString,
                _registered_method=True)
        self.ExportJsonEntityReport = channel.unary_unary(
                '/szengine.SzEngine/ExportJsonEntityReport',
                request_serializer=szengine__pb2.ExportJsonEntityReportRequest.SerializeToString,
                response_deserializer=szengine__pb2.ExportJsonEntityReportResponse.FromString,
                _registered_method=True)
        self.FetchNext = channel.unary_unary(
                '/szengine.SzEngine/FetchNext',
                request_serializer=szengine__pb2.FetchNextRequest.SerializeToString,
                response_deserializer=szengine__pb2.FetchNextResponse.FromString,
                _registered_method=True)
        self.FindInterestingEntitiesByEntityId = channel.unary_unary(
                '/szengine.SzEngine/FindInterestingEntitiesByEntityId',
                request_serializer=szengine__pb2.FindInterestingEntitiesByEntityIdRequest.SerializeToString,
                response_deserializer=szengine__pb2.FindInterestingEntitiesByEntityIdResponse.FromString,
                _registered_method=True)
        self.FindInterestingEntitiesByRecordId = channel.unary_unary(
                '/szengine.SzEngine/FindInterestingEntitiesByRecordId',
                request_serializer=szengine__pb2.FindInterestingEntitiesByRecordIdRequest.SerializeToString,
                response_deserializer=szengine__pb2.FindInterestingEntitiesByRecordIdResponse.FromString,
                _registered_method=True)
        self.FindNetworkByEntityId = channel.unary_unary(
                '/szengine.SzEngine/FindNetworkByEntityId',
                request_serializer=szengine__pb2.FindNetworkByEntityIdRequest.SerializeToString,
                response_deserializer=szengine__pb2.FindNetworkByEntityIdResponse.FromString,
                _registered_method=True)
        self.FindNetworkByRecordId = channel.unary_unary(
                '/szengine.SzEngine/FindNetworkByRecordId',
                request_serializer=szengine__pb2.FindNetworkByRecordIdRequest.SerializeToString,
                response_deserializer=szengine__pb2.FindNetworkByRecordIdResponse.FromString,
                _registered_method=True)
        self.FindPathByEntityId = channel.unary_unary(
                '/szengine.SzEngine/FindPathByEntityId',
                request_serializer=szengine__pb2.FindPathByEntityIdRequest.SerializeToString,
                response_deserializer=szengine__pb2.FindPathByEntityIdResponse.FromString,
                _registered_method=True)
        self.FindPathByRecordId = channel.unary_unary(
                '/szengine.SzEngine/FindPathByRecordId',
                request_serializer=szengine__pb2.FindPathByRecordIdRequest.SerializeToString,
                response_deserializer=szengine__pb2.FindPathByRecordIdResponse.FromString,
                _registered_method=True)
        self.GetActiveConfigId = channel.unary_unary(
                '/szengine.SzEngine/GetActiveConfigId',
                request_serializer=szengine__pb2.GetActiveConfigIdRequest.SerializeToString,
                response_deserializer=szengine__pb2.GetActiveConfigIdResponse.FromString,
                _registered_method=True)
        self.GetEntityByEntityId = channel.unary_unary(
                '/szengine.SzEngine/GetEntityByEntityId',
                request_serializer=szengine__pb2.GetEntityByEntityIdRequest.SerializeToString,
                response_deserializer=szengine__pb2.GetEntityByEntityIdResponse.FromString,
                _registered_method=True)
        self.GetEntityByRecordId = channel.unary_unary(
                '/szengine.SzEngine/GetEntityByRecordId',
                request_serializer=szengine__pb2.GetEntityByRecordIdRequest.SerializeToString,
                response_deserializer=szengine__pb2.GetEntityByRecordIdResponse.FromString,
                _registered_method=True)
        self.GetRecord = channel.unary_unary(
                '/szengine.SzEngine/GetRecord',
                request_serializer=szengine__pb2.GetRecordRequest.SerializeToString,
                response_deserializer=szengine__pb2.GetRecordResponse.FromString,
                _registered_method=True)
        self.GetRedoRecord = channel.unary_unary(
                '/szengine.SzEngine/GetRedoRecord',
                request_serializer=szengine__pb2.GetRedoRecordRequest.SerializeToString,
                response_deserializer=szengine__pb2.GetRedoRecordResponse.FromString,
                _registered_method=True)
        self.GetStats = channel.unary_unary(
                '/szengine.SzEngine/GetStats',
                request_serializer=szengine__pb2.GetStatsRequest.SerializeToString,
                response_deserializer=szengine__pb2.GetStatsResponse.FromString,
                _registered_method=True)
        self.GetVirtualEntityByRecordId = channel.unary_unary(
                '/szengine.SzEngine/GetVirtualEntityByRecordId',
                request_serializer=szengine__pb2.GetVirtualEntityByRecordIdRequest.SerializeToString,
                response_deserializer=szengine__pb2.GetVirtualEntityByRecordIdResponse.FromString,
                _registered_method=True)
        self.HowEntityByEntityId = channel.unary_unary(
                '/szengine.SzEngine/HowEntityByEntityId',
                request_serializer=szengine__pb2.HowEntityByEntityIdRequest.SerializeToString,
                response_deserializer=szengine__pb2.HowEntityByEntityIdResponse.FromString,
                _registered_method=True)
        self.PreprocessRecord = channel.unary_unary(
                '/szengine.SzEngine/PreprocessRecord',
                request_serializer=szengine__pb2.PreprocessRecordRequest.SerializeToString,
                response_deserializer=szengine__pb2.PreprocessRecordResponse.FromString,
                _registered_method=True)
        self.PrimeEngine = channel.unary_unary(
                '/szengine.SzEngine/PrimeEngine',
                request_serializer=szengine__pb2.PrimeEngineRequest.SerializeToString,
                response_deserializer=szengine__pb2.PrimeEngineResponse.FromString,
                _registered_method=True)
        self.ProcessRedoRecord = channel.unary_unary(
                '/szengine.SzEngine/ProcessRedoRecord',
                request_serializer=szengine__pb2.ProcessRedoRecordRequest.SerializeToString,
                response_deserializer=szengine__pb2.ProcessRedoRecordResponse.FromString,
                _registered_method=True)
        self.ReevaluateEntity = channel.unary_unary(
                '/szengine.SzEngine/ReevaluateEntity',
                request_serializer=szengine__pb2.ReevaluateEntityRequest.SerializeToString,
                response_deserializer=szengine__pb2.ReevaluateEntityResponse.FromString,
                _registered_method=True)
        self.ReevaluateRecord = channel.unary_unary(
                '/szengine.SzEngine/ReevaluateRecord',
                request_serializer=szengine__pb2.ReevaluateRecordRequest.SerializeToString,
                response_deserializer=szengine__pb2.ReevaluateRecordResponse.FromString,
                _registered_method=True)
        self.Reinitialize = channel.unary_unary(
                '/szengine.SzEngine/Reinitialize',
                request_serializer=szengine__pb2.ReinitializeRequest.SerializeToString,
                response_deserializer=szengine__pb2.ReinitializeResponse.FromString,
                _registered_method=True)
        self.SearchByAttributes = channel.unary_unary(
                '/szengine.SzEngine/SearchByAttributes',
                request_serializer=szengine__pb2.SearchByAttributesRequest.SerializeToString,
                response_deserializer=szengine__pb2.SearchByAttributesResponse.FromString,
                _registered_method=True)
        self.StreamExportCsvEntityReport = channel.unary_stream(
                '/szengine.SzEngine/StreamExportCsvEntityReport',
                request_serializer=szengine__pb2.StreamExportCsvEntityReportRequest.SerializeToString,
                response_deserializer=szengine__pb2.StreamExportCsvEntityReportResponse.FromString,
                _registered_method=True)
        self.StreamExportJsonEntityReport = channel.unary_stream(
                '/szengine.SzEngine/StreamExportJsonEntityReport',
                request_serializer=szengine__pb2.StreamExportJsonEntityReportRequest.SerializeToString,
                response_deserializer=szengine__pb2.StreamExportJsonEntityReportResponse.FromString,
                _registered_method=True)
        self.WhyEntities = channel.unary_unary(
                '/szengine.SzEngine/WhyEntities',
                request_serializer=szengine__pb2.WhyEntitiesRequest.SerializeToString,
                response_deserializer=szengine__pb2.WhyEntitiesResponse.FromString,
                _registered_method=True)
        self.WhyRecordInEntity = channel.unary_unary(
                '/szengine.SzEngine/WhyRecordInEntity',
                request_serializer=szengine__pb2.WhyRecordInEntityRequest.SerializeToString,
                response_deserializer=szengine__pb2.WhyRecordInEntityResponse.FromString,
                _registered_method=True)
        self.WhyRecords = channel.unary_unary(
                '/szengine.SzEngine/WhyRecords',
                request_serializer=szengine__pb2.WhyRecordsRequest.SerializeToString,
                response_deserializer=szengine__pb2.WhyRecordsResponse.FromString,
                _registered_method=True)
        self.WhySearch = channel.unary_unary(
                '/szengine.SzEngine/WhySearch',
                request_serializer=szengine__pb2.WhySearchRequest.SerializeToString,
                response_deserializer=szengine__pb2.WhySearchResponse.FromString,
                _registered_method=True)


class SzEngineServicer(object):
    """Missing associated documentation comment in .proto file."""

    def AddRecord(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CloseExport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CountRedoRecords(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteRecord(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExportCsvEntityReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExportJsonEntityReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FetchNext(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindInterestingEntitiesByEntityId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindInterestingEntitiesByRecordId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindNetworkByEntityId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindNetworkByRecordId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindPathByEntityId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindPathByRecordId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetActiveConfigId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEntityByEntityId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEntityByRecordId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRecord(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRedoRecord(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetStats(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetVirtualEntityByRecordId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HowEntityByEntityId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PreprocessRecord(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PrimeEngine(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ProcessRedoRecord(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReevaluateEntity(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReevaluateRecord(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Reinitialize(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchByAttributes(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamExportCsvEntityReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamExportJsonEntityReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WhyEntities(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WhyRecordInEntity(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WhyRecords(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WhySearch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SzEngineServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'AddRecord': grpc.unary_unary_rpc_method_handler(
                    servicer.AddRecord,
                    request_deserializer=szengine__pb2.AddRecordRequest.FromString,
                    response_serializer=szengine__pb2.AddRecordResponse.SerializeToString,
            ),
            'CloseExport': grpc.unary_unary_rpc_method_handler(
                    servicer.CloseExport,
                    request_deserializer=szengine__pb2.CloseExportRequest.FromString,
                    response_serializer=szengine__pb2.CloseExportResponse.SerializeToString,
            ),
            'CountRedoRecords': grpc.unary_unary_rpc_method_handler(
                    servicer.CountRedoRecords,
                    request_deserializer=szengine__pb2.CountRedoRecordsRequest.FromString,
                    response_serializer=szengine__pb2.CountRedoRecordsResponse.SerializeToString,
            ),
            'DeleteRecord': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteRecord,
                    request_deserializer=szengine__pb2.DeleteRecordRequest.FromString,
                    response_serializer=szengine__pb2.DeleteRecordResponse.SerializeToString,
            ),
            'ExportCsvEntityReport': grpc.unary_unary_rpc_method_handler(
                    servicer.ExportCsvEntityReport,
                    request_deserializer=szengine__pb2.ExportCsvEntityReportRequest.FromString,
                    response_serializer=szengine__pb2.ExportCsvEntityReportResponse.SerializeToString,
            ),
            'ExportJsonEntityReport': grpc.unary_unary_rpc_method_handler(
                    servicer.ExportJsonEntityReport,
                    request_deserializer=szengine__pb2.ExportJsonEntityReportRequest.FromString,
                    response_serializer=szengine__pb2.ExportJsonEntityReportResponse.SerializeToString,
            ),
            'FetchNext': grpc.unary_unary_rpc_method_handler(
                    servicer.FetchNext,
                    request_deserializer=szengine__pb2.FetchNextRequest.FromString,
                    response_serializer=szengine__pb2.FetchNextResponse.SerializeToString,
            ),
            'FindInterestingEntitiesByEntityId': grpc.unary_unary_rpc_method_handler(
                    servicer.FindInterestingEntitiesByEntityId,
                    request_deserializer=szengine__pb2.FindInterestingEntitiesByEntityIdRequest.FromString,
                    response_serializer=szengine__pb2.FindInterestingEntitiesByEntityIdResponse.SerializeToString,
            ),
            'FindInterestingEntitiesByRecordId': grpc.unary_unary_rpc_method_handler(
                    servicer.FindInterestingEntitiesByRecordId,
                    request_deserializer=szengine__pb2.FindInterestingEntitiesByRecordIdRequest.FromString,
                    response_serializer=szengine__pb2.FindInterestingEntitiesByRecordIdResponse.SerializeToString,
            ),
            'FindNetworkByEntityId': grpc.unary_unary_rpc_method_handler(
                    servicer.FindNetworkByEntityId,
                    request_deserializer=szengine__pb2.FindNetworkByEntityIdRequest.FromString,
                    response_serializer=szengine__pb2.FindNetworkByEntityIdResponse.SerializeToString,
            ),
            'FindNetworkByRecordId': grpc.unary_unary_rpc_method_handler(
                    servicer.FindNetworkByRecordId,
                    request_deserializer=szengine__pb2.FindNetworkByRecordIdRequest.FromString,
                    response_serializer=szengine__pb2.FindNetworkByRecordIdResponse.SerializeToString,
            ),
            'FindPathByEntityId': grpc.unary_unary_rpc_method_handler(
                    servicer.FindPathByEntityId,
                    request_deserializer=szengine__pb2.FindPathByEntityIdRequest.FromString,
                    response_serializer=szengine__pb2.FindPathByEntityIdResponse.SerializeToString,
            ),
            'FindPathByRecordId': grpc.unary_unary_rpc_method_handler(
                    servicer.FindPathByRecordId,
                    request_deserializer=szengine__pb2.FindPathByRecordIdRequest.FromString,
                    response_serializer=szengine__pb2.FindPathByRecordIdResponse.SerializeToString,
            ),
            'GetActiveConfigId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetActiveConfigId,
                    request_deserializer=szengine__pb2.GetActiveConfigIdRequest.FromString,
                    response_serializer=szengine__pb2.GetActiveConfigIdResponse.SerializeToString,
            ),
            'GetEntityByEntityId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEntityByEntityId,
                    request_deserializer=szengine__pb2.GetEntityByEntityIdRequest.FromString,
                    response_serializer=szengine__pb2.GetEntityByEntityIdResponse.SerializeToString,
            ),
            'GetEntityByRecordId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEntityByRecordId,
                    request_deserializer=szengine__pb2.GetEntityByRecordIdRequest.FromString,
                    response_serializer=szengine__pb2.GetEntityByRecordIdResponse.SerializeToString,
            ),
            'GetRecord': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRecord,
                    request_deserializer=szengine__pb2.GetRecordRequest.FromString,
                    response_serializer=szengine__pb2.GetRecordResponse.SerializeToString,
            ),
            'GetRedoRecord': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRedoRecord,
                    request_deserializer=szengine__pb2.GetRedoRecordRequest.FromString,
                    response_serializer=szengine__pb2.GetRedoRecordResponse.SerializeToString,
            ),
            'GetStats': grpc.unary_unary_rpc_method_handler(
                    servicer.GetStats,
                    request_deserializer=szengine__pb2.GetStatsRequest.FromString,
                    response_serializer=szengine__pb2.GetStatsResponse.SerializeToString,
            ),
            'GetVirtualEntityByRecordId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetVirtualEntityByRecordId,
                    request_deserializer=szengine__pb2.GetVirtualEntityByRecordIdRequest.FromString,
                    response_serializer=szengine__pb2.GetVirtualEntityByRecordIdResponse.SerializeToString,
            ),
            'HowEntityByEntityId': grpc.unary_unary_rpc_method_handler(
                    servicer.HowEntityByEntityId,
                    request_deserializer=szengine__pb2.HowEntityByEntityIdRequest.FromString,
                    response_serializer=szengine__pb2.HowEntityByEntityIdResponse.SerializeToString,
            ),
            'PreprocessRecord': grpc.unary_unary_rpc_method_handler(
                    servicer.PreprocessRecord,
                    request_deserializer=szengine__pb2.PreprocessRecordRequest.FromString,
                    response_serializer=szengine__pb2.PreprocessRecordResponse.SerializeToString,
            ),
            'PrimeEngine': grpc.unary_unary_rpc_method_handler(
                    servicer.PrimeEngine,
                    request_deserializer=szengine__pb2.PrimeEngineRequest.FromString,
                    response_serializer=szengine__pb2.PrimeEngineResponse.SerializeToString,
            ),
            'ProcessRedoRecord': grpc.unary_unary_rpc_method_handler(
                    servicer.ProcessRedoRecord,
                    request_deserializer=szengine__pb2.ProcessRedoRecordRequest.FromString,
                    response_serializer=szengine__pb2.ProcessRedoRecordResponse.SerializeToString,
            ),
            'ReevaluateEntity': grpc.unary_unary_rpc_method_handler(
                    servicer.ReevaluateEntity,
                    request_deserializer=szengine__pb2.ReevaluateEntityRequest.FromString,
                    response_serializer=szengine__pb2.ReevaluateEntityResponse.SerializeToString,
            ),
            'ReevaluateRecord': grpc.unary_unary_rpc_method_handler(
                    servicer.ReevaluateRecord,
                    request_deserializer=szengine__pb2.ReevaluateRecordRequest.FromString,
                    response_serializer=szengine__pb2.ReevaluateRecordResponse.SerializeToString,
            ),
            'Reinitialize': grpc.unary_unary_rpc_method_handler(
                    servicer.Reinitialize,
                    request_deserializer=szengine__pb2.ReinitializeRequest.FromString,
                    response_serializer=szengine__pb2.ReinitializeResponse.SerializeToString,
            ),
            'SearchByAttributes': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchByAttributes,
                    request_deserializer=szengine__pb2.SearchByAttributesRequest.FromString,
                    response_serializer=szengine__pb2.SearchByAttributesResponse.SerializeToString,
            ),
            'StreamExportCsvEntityReport': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamExportCsvEntityReport,
                    request_deserializer=szengine__pb2.StreamExportCsvEntityReportRequest.FromString,
                    response_serializer=szengine__pb2.StreamExportCsvEntityReportResponse.SerializeToString,
            ),
            'StreamExportJsonEntityReport': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamExportJsonEntityReport,
                    request_deserializer=szengine__pb2.StreamExportJsonEntityReportRequest.FromString,
                    response_serializer=szengine__pb2.StreamExportJsonEntityReportResponse.SerializeToString,
            ),
            'WhyEntities': grpc.unary_unary_rpc_method_handler(
                    servicer.WhyEntities,
                    request_deserializer=szengine__pb2.WhyEntitiesRequest.FromString,
                    response_serializer=szengine__pb2.WhyEntitiesResponse.SerializeToString,
            ),
            'WhyRecordInEntity': grpc.unary_unary_rpc_method_handler(
                    servicer.WhyRecordInEntity,
                    request_deserializer=szengine__pb2.WhyRecordInEntityRequest.FromString,
                    response_serializer=szengine__pb2.WhyRecordInEntityResponse.SerializeToString,
            ),
            'WhyRecords': grpc.unary_unary_rpc_method_handler(
                    servicer.WhyRecords,
                    request_deserializer=szengine__pb2.WhyRecordsRequest.FromString,
                    response_serializer=szengine__pb2.WhyRecordsResponse.SerializeToString,
            ),
            'WhySearch': grpc.unary_unary_rpc_method_handler(
                    servicer.WhySearch,
                    request_deserializer=szengine__pb2.WhySearchRequest.FromString,
                    response_serializer=szengine__pb2.WhySearchResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'szengine.SzEngine', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('szengine.SzEngine', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class SzEngine(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def AddRecord(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/AddRecord',
            szengine__pb2.AddRecordRequest.SerializeToString,
            szengine__pb2.AddRecordResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CloseExport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/CloseExport',
            szengine__pb2.CloseExportRequest.SerializeToString,
            szengine__pb2.CloseExportResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CountRedoRecords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/CountRedoRecords',
            szengine__pb2.CountRedoRecordsRequest.SerializeToString,
            szengine__pb2.CountRedoRecordsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteRecord(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/DeleteRecord',
            szengine__pb2.DeleteRecordRequest.SerializeToString,
            szengine__pb2.DeleteRecordResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ExportCsvEntityReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/ExportCsvEntityReport',
            szengine__pb2.ExportCsvEntityReportRequest.SerializeToString,
            szengine__pb2.ExportCsvEntityReportResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ExportJsonEntityReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/ExportJsonEntityReport',
            szengine__pb2.ExportJsonEntityReportRequest.SerializeToString,
            szengine__pb2.ExportJsonEntityReportResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def FetchNext(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/FetchNext',
            szengine__pb2.FetchNextRequest.SerializeToString,
            szengine__pb2.FetchNextResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def FindInterestingEntitiesByEntityId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/FindInterestingEntitiesByEntityId',
            szengine__pb2.FindInterestingEntitiesByEntityIdRequest.SerializeToString,
            szengine__pb2.FindInterestingEntitiesByEntityIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def FindInterestingEntitiesByRecordId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/FindInterestingEntitiesByRecordId',
            szengine__pb2.FindInterestingEntitiesByRecordIdRequest.SerializeToString,
            szengine__pb2.FindInterestingEntitiesByRecordIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def FindNetworkByEntityId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/FindNetworkByEntityId',
            szengine__pb2.FindNetworkByEntityIdRequest.SerializeToString,
            szengine__pb2.FindNetworkByEntityIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def FindNetworkByRecordId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/FindNetworkByRecordId',
            szengine__pb2.FindNetworkByRecordIdRequest.SerializeToString,
            szengine__pb2.FindNetworkByRecordIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def FindPathByEntityId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/FindPathByEntityId',
            szengine__pb2.FindPathByEntityIdRequest.SerializeToString,
            szengine__pb2.FindPathByEntityIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def FindPathByRecordId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/FindPathByRecordId',
            szengine__pb2.FindPathByRecordIdRequest.SerializeToString,
            szengine__pb2.FindPathByRecordIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetActiveConfigId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/GetActiveConfigId',
            szengine__pb2.GetActiveConfigIdRequest.SerializeToString,
            szengine__pb2.GetActiveConfigIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetEntityByEntityId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/GetEntityByEntityId',
            szengine__pb2.GetEntityByEntityIdRequest.SerializeToString,
            szengine__pb2.GetEntityByEntityIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetEntityByRecordId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/GetEntityByRecordId',
            szengine__pb2.GetEntityByRecordIdRequest.SerializeToString,
            szengine__pb2.GetEntityByRecordIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetRecord(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/GetRecord',
            szengine__pb2.GetRecordRequest.SerializeToString,
            szengine__pb2.GetRecordResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetRedoRecord(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/GetRedoRecord',
            szengine__pb2.GetRedoRecordRequest.SerializeToString,
            szengine__pb2.GetRedoRecordResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/GetStats',
            szengine__pb2.GetStatsRequest.SerializeToString,
            szengine__pb2.GetStatsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetVirtualEntityByRecordId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/GetVirtualEntityByRecordId',
            szengine__pb2.GetVirtualEntityByRecordIdRequest.SerializeToString,
            szengine__pb2.GetVirtualEntityByRecordIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def HowEntityByEntityId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/HowEntityByEntityId',
            szengine__pb2.HowEntityByEntityIdRequest.SerializeToString,
            szengine__pb2.HowEntityByEntityIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PreprocessRecord(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/PreprocessRecord',
            szengine__pb2.PreprocessRecordRequest.SerializeToString,
            szengine__pb2.PreprocessRecordResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PrimeEngine(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/PrimeEngine',
            szengine__pb2.PrimeEngineRequest.SerializeToString,
            szengine__pb2.PrimeEngineResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ProcessRedoRecord(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/ProcessRedoRecord',
            szengine__pb2.ProcessRedoRecordRequest.SerializeToString,
            szengine__pb2.ProcessRedoRecordResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ReevaluateEntity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/ReevaluateEntity',
            szengine__pb2.ReevaluateEntityRequest.SerializeToString,
            szengine__pb2.ReevaluateEntityResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ReevaluateRecord(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/ReevaluateRecord',
            szengine__pb2.ReevaluateRecordRequest.SerializeToString,
            szengine__pb2.ReevaluateRecordResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Reinitialize(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/Reinitialize',
            szengine__pb2.ReinitializeRequest.SerializeToString,
            szengine__pb2.ReinitializeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SearchByAttributes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/SearchByAttributes',
            szengine__pb2.SearchByAttributesRequest.SerializeToString,
            szengine__pb2.SearchByAttributesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StreamExportCsvEntityReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/szengine.SzEngine/StreamExportCsvEntityReport',
            szengine__pb2.StreamExportCsvEntityReportRequest.SerializeToString,
            szengine__pb2.StreamExportCsvEntityReportResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StreamExportJsonEntityReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/szengine.SzEngine/StreamExportJsonEntityReport',
            szengine__pb2.StreamExportJsonEntityReportRequest.SerializeToString,
            szengine__pb2.StreamExportJsonEntityReportResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def WhyEntities(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/WhyEntities',
            szengine__pb2.WhyEntitiesRequest.SerializeToString,
            szengine__pb2.WhyEntitiesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def WhyRecordInEntity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/WhyRecordInEntity',
            szengine__pb2.WhyRecordInEntityRequest.SerializeToString,
            szengine__pb2.WhyRecordInEntityResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def WhyRecords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/WhyRecords',
            szengine__pb2.WhyRecordsRequest.SerializeToString,
            szengine__pb2.WhyRecordsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def WhySearch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/szengine.SzEngine/WhySearch',
            szengine__pb2.WhySearchRequest.SerializeToString,
            szengine__pb2.WhySearchResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
